changeset 50562:6ee9d94eaca3

(f90-abbrev-start): Only offer help if abbrev-mode is active.
author Glenn Morris <rgm@gnu.org>
date Sat, 12 Apr 2003 15:45:59 +0000
parents aab211655bcd
children 23dfa4b79c21
files lisp/progmodes/f90.el
diffstat 1 files changed, 2 insertions(+), 2 deletions(-) [+]
line wrap: on
line diff
--- a/lisp/progmodes/f90.el	Sat Apr 12 15:44:59 2003 +0000
+++ b/lisp/progmodes/f90.el	Sat Apr 12 15:45:59 2003 +0000
@@ -1677,8 +1677,8 @@
     (setq c (if (fboundp 'next-command-event) ; XEmacs
                 (event-to-character (next-command-event))
               (read-event)))
-    ;; Insert char if not equal to `?'.
-    (if (or (eq c ??) (eq c help-char))
+    ;; Insert char if not equal to `?', or if abbrev-mode is off.
+    (if (and abbrev-mode (or (eq c ??) (eq c help-char)))
 	(f90-abbrev-help)
       (setq unread-command-events (list c)))))